# INSTALL

- 从 [PyPI][] 安装

  ```bash
  pip install ks33requests
  ```

- 从源代码安装

  ```bash
  python setuptools.py install
  ```

- 使用 [Pipenv][] 安装

  ```bash
  pipenv install ks33requests
  ```

[PyPI]: https://pypi.org/ "The Python Package Index (PyPI) is a repository of software for the Python programming language."
[Pipenv]: https://packaging.python.org/key_projects/#pipenv
